import { reset, CSS_VARS, stylePropsToCSS } from '@raam/core';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

const propsWithoutUndefined = obj => Object.keys(obj).reduce((acc, key) => {
  if (obj[key] !== undefined) acc[key] = obj[key];
  return acc;
}, {});

const flexboxVariants = {
  vStack: {
    gap: "1rem",
    flexDirection: "column",
    flexWrap: "nowrap"
  },
  hStack: {
    gap: "1rem",
    flexDirection: "row",
    flexWrap: "nowrap"
  },
  wrap: {
    gap: "1rem",
    alignItems: "center",
    flexDirection: "row",
    flexWrap: "wrap",
    justifyContent: "flex-start"
  }
};

const parent = (_ref) => {
  let {
    gap: flexGap,
    withoutBaseStyles,
    withoutElementStyles
  } = _ref,
      props = _objectWithoutPropertiesLoose(_ref, ["gap", "withoutBaseStyles", "withoutElementStyles"]);

  return _extends({}, withoutBaseStyles && reset, !withoutElementStyles && {
    /**
     * `ul`
     * Override browser defaults
     */
    paddingLeft: 0
  }, {
    display: "flex",
    margin: `var(${CSS_VARS.FLEX_GAP_OFFSET}, initial)`
  }, stylePropsToCSS(_extends({
    flexGap
  }, props)));
};

const child = ({
  flex: _flex = "0 0 auto",
  flexBasis,
  flexGrow,
  flexShrink,
  index: _index = 1,
  withoutBaseStyles,
  withoutElementStyles,
  theme
}) => _extends({}, !withoutBaseStyles && reset, !withoutElementStyles && {
  /**
   * `li`
   * Ensure any list-items are rendered without bullets.
   * Adding a zero-width space in the content to prevent VoiceOver disable.
   */
  listStyleType: "none",
  "&:before": {
    position: "absolute",
    content: '"\\200B"'
  }
}, {
  marginTop: `var(${CSS_VARS.FLEX_GAP}, ${_index > 0 ? `var(${CSS_VARS.FLEX_GAP_TOP}, initial)` : "initial"})`,
  marginRight: `var(${CSS_VARS.FLEX_GAP}, initial)`,
  marginBottom: `var(${CSS_VARS.FLEX_GAP}, initial)`,
  marginLeft: `var(${CSS_VARS.FLEX_GAP}, ${_index > 0 ? `var(${CSS_VARS.FLEX_GAP_LEFT}, initial)` : "initial"})`
}, stylePropsToCSS({
  flex: _flex,
  flexBasis,
  flexGrow,
  flexShrink,
  theme
}));

const flexbox = props => {
  const variant = (props == null ? void 0 : props.variant) || "hStack"; // @TODO Support Responsive Variants

  const propsWithVariant = variant ? _extends({}, flexboxVariants[variant], props && propsWithoutUndefined(props)) : propsWithoutUndefined(props);
  return {
    parent: () => parent(_extends({}, propsWithVariant)),
    child: childProps => child(childProps ? _extends({}, childProps, propsWithVariant) : propsWithVariant)
  };
};

export { flexbox };
//# sourceMappingURL=index.modern.js.map
